import { Card, Checkbox, Form, Radio, Select, Space, Switch, Tooltip } from "antd"
import React, { useContext, useEffect, useMemo, useState } from "react"
import { DispatchDynamic } from "./newDynamic";
import style from '../index.less'
import New1Radio from "@/pages/launchSystemV3/components/New1Radio";
import { useUpdateEffect } from "ahooks";
import { QuestionCircleFilled } from "@ant-design/icons";

/**
 * 营销组件
 * @returns 
 */
const CreativeConversionAssistant: React.FC<{ automaticSiteEnabled?: boolean }> = ({ automaticSiteEnabled }) => {

    /**************************************/
    const { creativeComponents, form, isUpdate, setIsUpdate } = useContext(DispatchDynamic)!;
    const textLinkShow = Form.useWatch('textLinkShow', form)
    const actionButtonShow = Form.useWatch('actionButtonShow', form)
    const showDataShow = Form.useWatch('showDataShow', form)
    const pageSpec = Form.useWatch('pageSpec', form)
    const linkNameType = Form.useWatch(['textLink', 'value', 'linkNameType'], form)
    const conversionDataType = Form.useWatch(['showData', 'value', 'conversionDataType'], form)
    const conversionTargetType = Form.useWatch(['showData', 'value', 'conversionTargetType'], form)
    const creativeTemplateId = Form.useWatch('creativeTemplateId', form)
    const cardType: string[] = Form.useWatch('cardType', form)
    const [cardData, setCardData] = useState<{ label: string, value: string, disabled?: boolean }[]>([])
    /**************************************/

    useUpdateEffect(() => {
        if (isUpdate) {
            setDefaultShouData()
        }
    }, [linkNameType, conversionDataType, conversionTargetType, showDataShow, creativeComponents?.show_data, isUpdate])

    const setDefaultShouData = () => {
        setIsUpdate(false)
        if (showDataShow && creativeComponents?.show_data) {
            let showData = creativeComponents?.show_data;
            let link_name_type = linkNameType || ''
            let conversionDataTypeData = showData?.children?.conversion_data_type
            let values: any = {}
            if (conversionDataTypeData) {
                let conversionDataTypeEnumeration = (conversionDataTypeData.enumProperty.enumeration as { value: string, category: string, description: string }[])
                    .filter(item => item.category === link_name_type)
                    .map(item => item.value)
                if (conversionDataTypeEnumeration.length === 0) {
                    conversionDataTypeEnumeration = (conversionDataTypeData.enumProperty.enumeration as { value: string, category: string, description: string }[])
                        .filter(item => item.category === '')
                        .map(item => item.value)
                }
                if (!conversionDataTypeEnumeration.includes(conversionDataType)) {
                    values.conversionDataType = conversionDataTypeEnumeration?.[0]
                }
            }
            let conversionTargetTypeData = showData?.children?.conversion_target_type
            if (conversionTargetTypeData) {
                let conversionTargetTypeEnumeration = (conversionTargetTypeData.enumProperty.enumeration as { value: string, category: string, description: string }[])
                    .filter(item => item.category === link_name_type)
                    .map(item => item.value)
                if (conversionTargetTypeEnumeration.length === 0) {
                    conversionTargetTypeEnumeration = (conversionTargetTypeData.enumProperty.enumeration as { value: string, category: string, description: string }[])
                        .filter(item => item.category === '')
                        .map(item => item.value)
                }
                if (!conversionTargetTypeEnumeration.includes(conversionTargetType)) {
                    values.conversionTargetType = conversionTargetTypeEnumeration?.[0]
                }
            }
            let valueKeys = Object.keys(values)
            if (valueKeys.length > 0) {
                if (!valueKeys.includes('conversionTargetType')) {
                    values.conversionTargetType = conversionTargetType
                }
                if (!valueKeys.includes('conversionDataType')) {
                    values.conversionDataType = conversionDataType
                }
                console.log('values--->', values)
                form.setFieldsValue({
                    showData: {
                        value: values
                    }
                })
            }
        }
    }

    /** 微信文字链 */
    const textLinkContent = useMemo(() => {
        let textLink = creativeComponents?.text_link
        if (textLink && ![1707, 1708].includes(creativeTemplateId) && !automaticSiteEnabled) {
            let pageSpecPageType = pageSpec?.[0]?.pageType || 'PAGE_TYPE_WECHAT_CANVAS'
            let textLinkRequired, linkNameEnumeration: { label: string, value: string }[] = [];
            let linkNamePageType, linkNamePageTypeEnumeration: PULLIN.DataType[] = [];
            textLinkRequired = textLink.required
            let linkNameType = textLink.children.link_name_type
            linkNameEnumeration = (linkNameType.enumProperty.enumeration as { value: string, description: string }[]).map(item => ({ label: item.description, value: item.value }))
            linkNamePageType = textLink?.children?.page_type
            if (linkNamePageType) {
                linkNamePageTypeEnumeration = (linkNamePageType?.enumProperty?.enumeration as { value: string, description: string }[]).filter(item => item.value === pageSpecPageType).map(item => ({ label: item.description, value: item.value }))
            }

            return <Form.Item style={{ marginBottom: 0 }}>
                <div className={style.newSpace}>
                    <div className={style.newSpace_top}>
                        <div className={style.newSpace_title}>朋友圈文字链</div>
                        <Form.Item name={'textLinkShow'} valuePropName="checked" style={{ marginBottom: 0 }}>
                            <Switch disabled={textLinkRequired} onChange={() => setIsUpdate(true)} />
                        </Form.Item>
                    </div>
                </div>
                {textLinkShow && <Card bordered className="cardResetCss newCss" bodyStyle={{ padding: 0 }}>
                    <div className={style.newSpace}>
                        <div className={style.newSpace_top}>
                            <div className={style.newSpace_title}>文字链文案</div>
                            <Form.Item
                                name={['textLink', 'value', 'linkNameType']}
                                rules={[{ required: true, message: '请选择文字链文案' }]}
                                style={{ marginBottom: 0 }}
                            >
                                <Select
                                    style={{ width: 480 }}
                                    showSearch
                                    placeholder="请选择文字链文案"
                                    optionFilterProp="children"
                                    filterOption={(input, option: any) =>
                                        (option?.label ?? '').toLowerCase().includes(input.toLowerCase())
                                    }
                                    onChange={() => setIsUpdate(true)}
                                    options={linkNameEnumeration}
                                />
                            </Form.Item>
                        </div>
                    </div>
                    {linkNamePageType && <div className={style.newSpace}>
                        <div className={style.newSpace_top}>
                            <div className={style.newSpace_title}>跳转落地页</div>
                            <Form.Item
                                name={['textLink', 'value', 'jumpInfo', 'pageType']}
                                rules={[{ required: true, message: '请选择跳转落地页类型' }]}
                                style={{ marginBottom: 0 }}
                            >
                                <New1Radio data={linkNamePageTypeEnumeration} />
                            </Form.Item>
                        </div>
                    </div>}
                </Card>}
            </Form.Item>
        }
        return null
    }, [creativeComponents?.text_link, pageSpec, textLinkShow, creativeTemplateId, automaticSiteEnabled])

    /** 行动按钮 */
    const actionButtonContent = useMemo(() => {
        // 卡片广告用卡片组件控制
        if ([1707, 1708].includes(creativeTemplateId) && !cardType?.includes('action_button')) {
            return null
        }
        let actionButton = creativeComponents?.action_button
        if (actionButton) {
            let pageSpecPageType = pageSpec?.[0]?.pageType || 'PAGE_TYPE_WECHAT_CANVAS'
            let actionButtonRequired, butttonTextEnumeration: { label: string, value: string }[] = [];
            let actionButtonPageType, actionButtonPageTypeEnumeration: PULLIN.DataType[] = [];
            actionButtonRequired = actionButton.required
            let buttonText = actionButton.children.button_text
            butttonTextEnumeration = (buttonText.enumProperty.enumeration as { value: string }[]).map(item => ({ label: item.value, value: item.value }))
            actionButtonPageType = actionButton?.children?.page_type
            if (actionButtonPageType) {
                actionButtonPageTypeEnumeration = (actionButtonPageType?.enumProperty?.enumeration as { value: string, description: string }[]).filter(item => item.value === pageSpecPageType).map(item => ({ label: item.description, value: item.value }))
            }

            return <Form.Item style={{ marginBottom: 0 }}>
                {![1707, 1708].includes(creativeTemplateId) && <div className={style.newSpace}>
                    <div className={style.newSpace_top}>
                        <div className={style.newSpace_title}>行动按钮</div>
                        <Form.Item name={'actionButtonShow'} valuePropName="checked" style={{ marginBottom: 0 }}>
                            <Switch disabled={actionButtonRequired} />
                        </Form.Item>
                    </div>
                </div>}
                {(actionButtonShow || cardType?.includes('action_button')) && <Card bordered className="cardResetCss newCss" bodyStyle={{ padding: 0 }}>
                    <div className={style.newSpace}>
                        <div className={style.newSpace_top}>
                            <div className={style.newSpace_title}>按钮文案</div>
                            <Form.Item
                                name={['actionButton', 'value', 'buttonText']}
                                rules={[{ required: true, message: '请选择按钮文案' }]}
                                style={{ marginBottom: 0 }}
                            >
                                <Select
                                    style={{ width: 480 }}
                                    showSearch
                                    placeholder="请选择按钮文案"
                                    optionFilterProp="children"
                                    filterOption={(input, option: any) =>
                                        (option?.label ?? '').toLowerCase().includes(input.toLowerCase())
                                    }
                                    options={butttonTextEnumeration}
                                />
                            </Form.Item>
                        </div>
                    </div>
                    {actionButtonPageType && <div className={style.newSpace}>
                        <div className={style.newSpace_top}>
                            <div className={style.newSpace_title}>跳转落地页</div>
                            <Form.Item
                                name={['actionButton', 'value', 'jumpInfo', 'pageType']}
                                rules={[{ required: true, message: '请选择跳转落地页类型' }]}
                                style={{ marginBottom: 0 }}
                            >
                                <New1Radio data={actionButtonPageTypeEnumeration} />
                            </Form.Item>
                        </div>
                    </div>}
                </Card>}
            </Form.Item>
        }
        return null
    }, [creativeComponents?.action_button, pageSpec, actionButtonShow, cardType, creativeTemplateId])

    const showDataContent = useMemo(() => {
        let showData = creativeComponents?.show_data;
        if (showData) {
            let conversionDataTypeEnumeration: PULLIN.DataType[] = [];
            let conversionTargetTypeEnumeration: PULLIN.DataType[] = [];
            let link_name_type = linkNameType || ''
            let showDataRequired = showData?.required
            let conversionDataType = showData?.children?.conversion_data_type
            if (conversionDataType) {
                conversionDataTypeEnumeration = (conversionDataType.enumProperty.enumeration as { value: string, category: string, description: string }[])
                    .filter(item => item.category === link_name_type)
                    .map(item => ({ label: item.description, value: item.value }))
                if (conversionDataTypeEnumeration.length === 0) {
                    conversionDataTypeEnumeration = (conversionDataType.enumProperty.enumeration as { value: string, category: string, description: string }[])
                        .filter(item => item.category === '')
                        .map(item => ({ label: item.description, value: item.value }))
                }
            }
            let conversionTargetType = showData?.children?.conversion_target_type
            if (conversionTargetType) {
                conversionTargetTypeEnumeration = (conversionTargetType.enumProperty.enumeration as { value: string, category: string, description: string }[])
                    .filter(item => item.category === link_name_type)
                    .map(item => ({ label: item.description, value: item.value }))
                if (conversionTargetTypeEnumeration.length === 0) {
                    conversionTargetTypeEnumeration = (conversionTargetType.enumProperty.enumeration as { value: string, category: string, description: string }[])
                        .filter(item => item.category === '')
                        .map(item => ({ label: item.description, value: item.value }))
                }
            }
            // 卡片广告去掉商品数据
            if ([1707, 1708].includes(creativeTemplateId)) {
                conversionDataTypeEnumeration = conversionDataTypeEnumeration.filter(item => item.value !== "CONVERSION_DATA_PRODUCT_DATA")
            }

            return <Form.Item style={{ marginBottom: 0 }}>
                <div className={style.newSpace}>
                    <div className={style.newSpace_top}>
                        <div className={style.newSpace_title}>数据外显</div>
                        <Form.Item name={'showDataShow'} valuePropName="checked" style={{ marginBottom: 0 }}>
                            <Switch disabled={showDataRequired} onChange={() => setIsUpdate(true)} />
                        </Form.Item>
                    </div>
                </div>
                {showDataShow && <Card bordered className="cardResetCss newCss" bodyStyle={{ padding: 0 }}>
                    <div className={style.newSpace}>
                        <div className={style.newSpace_top}>
                            <div className={style.newSpace_title}>数据类型</div>
                            <Form.Item
                                name={['showData', 'value', 'conversionDataType']}
                                rules={[{ required: true, message: '请选择数据类型' }]}
                                style={{ marginBottom: 0 }}
                            >
                                <Radio.Group options={conversionDataTypeEnumeration} />
                            </Form.Item>
                        </div>
                    </div>
                    <div className={style.newSpace}>
                        <div className={style.newSpace_top}>
                            <div className={style.newSpace_title}>转化行为</div>
                            <Form.Item
                                name={['showData', 'value', 'conversionTargetType']}
                                rules={[{ required: true, message: '请选择转化行为' }]}
                                style={{ marginBottom: 0 }}
                            >
                                <Radio.Group options={conversionTargetTypeEnumeration} />
                            </Form.Item>
                        </div>
                    </div>
                </Card>}
            </Form.Item>
        }
        return null
    }, [creativeComponents?.show_data, linkNameType, showDataShow, creativeTemplateId])


    useEffect(() => {
        let data = [
            { label: '不使用', value: 'not', disabled: false },
            { label: '行动按钮', value: 'action_button', disabled: cardType?.some(item => ['chosen_button', 'shop_imag'].includes(item)) },
            // { label: '选择按钮', value: 'chosen_button', disabled: cardType?.some(item => ['label', 'action_button', 'shop_imag'].includes(item)) },
            // { label: '卖点图', value: 'shop_imag', disabled: cardType?.some(item => ['chosen_button'].includes(item)) },
            // { label: '标签', value: 'label', disabled: cardType?.some(item => ['chosen_button', 'count_down'].includes(item)) },
            // { label: '倒计时', value: 'count_down', disabled: cardType?.some(item => ['living_desc', 'label'].includes(item)) },
            // { label: '轮播文案', value: 'living_desc', disabled: cardType?.some(item => ['count_down'].includes(item)) }
        ]
        if (cardType?.length >= 3) {
            setCardData(data.map(item => {
                if (cardType.includes(item.value)) {
                    return { ...item, disabled: false }
                } else if (item.value === 'not') {
                    return { ...item, disabled: false }
                } else {
                    return { ...item, disabled: true }
                }
            }))
        } else {
            setCardData(data)
        }
    }, [cardType])

    if (Object.keys(creativeComponents).some(key => ['text_link', 'action_button', 'show_data'].includes(key))) {
        return <Card
            title={<strong style={{ fontSize: 18 }}>营销组件</strong>}
            className="cardResetCss"
        >
            {/* 卡片广告所需 */}
            {[1707, 1708].includes(creativeTemplateId) && <Form.Item style={{ marginBottom: 0 }}>
                <div className={style.newSpace}>
                    <div className={style.newSpace_top}>
                        <div className={style.newSpace_title}>
                            <Space>
                                <strong>卡片组件</strong>
                                <Tooltip title={<div>
                                    卡片组件有以下使用条件：<br />
                                    1.卡片组件最多只能使用 3 个<br />
                                    2.倒计时不能与标签、轮播文案同时使用<br />
                                    3.卖点图必须与行动按钮同时使用<br />
                                    4.选择按钮不能与行动按钮、标签、卖点图同时使用
                                </div>}>
                                    <QuestionCircleFilled />
                                </Tooltip>
                            </Space>
                        </div>
                        <Form.Item
                            noStyle
                            name={'cardType'}
                            rules={[{ required: true, message: '请选择跳转落地页类型' }]}
                            style={{ marginBottom: 0 }}
                            getValueFromEvent={(e: string[]) => {
                                if (e.length > 1 && !cardType.includes('not') && e.includes('not')) {
                                    return ['not'];
                                }
                                if (e.includes('shop_imag') && !e.includes('action_button')) {
                                    e.push('action_button')
                                }
                                return e.length > 0 ? (e.length > 1 && e.includes('not') ? e.filter(item => item !== 'not') : e) : ['not'];
                            }}
                        >
                            <Checkbox.Group options={cardData} onChange={(e) => {
                                console.log(e)
                            }} />
                        </Form.Item>
                    </div>
                </div>

            </Form.Item>}
            {textLinkContent}
            {actionButtonContent}
            {showDataContent}
        </Card>
    } else {
        return null
    }
}

export default React.memo(CreativeConversionAssistant)